/* Xmsgd
 * Copyright (C) 2001 Thomas Vander Stichele <thomas@apestaart.org>
 *
 * Xmsglib.h: header for helper library for Xmsg and Xmsgd
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 */

#ifndef XMSGLIB_H
/* default values */

#define IMG_X 0
#define IMG_Y 0
#define IMG_W 50
#define IMG_H 50

#define MSG_X 50
#define MSG_Y 0
#define MSG_W 950
#define MSG_H 50

#define NOX_SLEEP_TIME 5

/* debug stuff */

extern char debug;
#define MYDEBUG(x) if (debug) { printf ("DEBUG: "); printf x; }

/* includes */

#include <X11/Xlib.h>
#include <sys/time.h>
#include <unistd.h>

/* structures */

typedef struct
{
  char *font_name;  
  char *color_name;
  float duration;
  float fade_time;
  char *icon_file;
  int line_number;
  char *text;
  char random;			/* do we want it at a randoom location ? */

  struct timeval kill_time;	/* at what time to kill the message */
  XFontStruct* font_info;       /* Font structure, used for drawing text */
  int display_width;
  int display_height;
  int text_width;
  int message_width, message_height;
  int font_height;

  Window img_w;
  Window msg_w;
} msg_t;

/* function prototypes */

/* these are wrapped up versions of the X functions for the perl interface */
Display* OpenDisplay 	(const char* display_name);
int	GetScreen	(Display* display);
void   	FlushDisplay 	(Display* display);
void    MoveWindow      (Display* display, Window window, int x, int y);

/* these are atomic functions */
Window 	CreateWindow 	(Display* display, int screen_num, int x, int y, 
			 int width, int height);
int 	LoadFont 	(Display* display, msg_t* msg);
int 	DrawXpm		(Display* display, Window window, char* xpm_file, int x, int y);
int	DrawText	(Display* display, Window window, const char* font,
			 const char* color, const char* text, int x, int y);
Window  DestroyWindow	(Display* display, Window window);

/* these are actual Xmsg functions */

int	DrawMsgText 	(Display* display, Window window, 
			 msg_t msg, char *text);
int 	DrawMsgXpm	(Display* display, Window window, msg_t msg);
void	DefaultMsg	(msg_t* msg);
void	ClearMsg	(msg_t* msg);
void	FreeMsg		(msg_t* msg);
void	KillMsg		(Display* display, msg_t* msg);

/* these are helper functions */
int	copy_string 	(char** dest, char* src, const char* dest_descr);
void	SetDebug	(char level);

#define XMSGLIB_H 1
#endif
